Pyexcel data renderers
=========================

There exist a few data renderers for pyexcel data. This chapter will walk you through them.

View pyexcel data in ndjson and other formats
-------------------------------------------------

With `pyexcel-text`_, you can get pyexcel data in newline delimited json, normal json and
other formats.

View the pyexcel data in a browser
------------------------------------------------

You can use `pyexcel-handsontable`_ to render your data.


Include excel data in your python documentation
--------------------------------------------------

`sphinxcontrib-excel`_ help you present your excel data in various formats inside your
sphinx documentation.

Draw charts from your excel data
--------------------------------------

`pyexcel-pygal`_ helps you with all charting options and give you charts in svg format.

`pyexcel-echarts`_  draws 2D, 3D, geo charts from pyexcel data and has awesome animations too, but
it is under development.

`pyexcel-matplotlib`_ helps you with scientific charts and is under developmement.

Gantt chart visualization for your excel data
-------------------------------------------------

`pyexcel-gantt`_ is a specialist renderer for gantt chart.


.. _pyexcel-text: https://github.com/pyexcel-renderers/pyexcel-text
.. _pyexcel-handsontable: https://github.com/pyexcel-renderers/pyexcel-handsontable
.. _pyexcel-pygal: https://github.com/pyexcel-renderers/pyexcel-pygal
.. _pyexcel-echarts: https://github.com/pyexcel-renderers/pyexcel-echarts
.. _pyexcel-matplotlib: https://github.com/pyexcel-renderers/pyexcel-matplotlib
.. _sphinxcontrib-excel: https://github.com/pyexcel-renderers/sphinxcontrib-excel
.. _pyexcel-gantt: https://github.com/pyexcel-renderers/pyexcel-gantt


